API Reference
=============

.. automodule:: PIconnect
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:

PI Data Archive related modules
-------------------------------

.. toctree::
   :maxdepth: 4
   :glob:

   ./PI/*

PI Asset Framework related modules
----------------------------------

.. toctree::
   :maxdepth: 4
   :glob:

   ./PIAF/*

Generic utility modules
-----------------------

.. toctree::
   :maxdepth: 4
   :glob:

   ./*
